package com.goldenwater.yjjt.service.impl;

import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.yjjt.domain.YjjtSzData;
import com.goldenwater.yjjt.mapper.YjjtSzDataMapper;
import com.goldenwater.yjjt.service.IYjjtSzDataService;

/**
 * 引江济太水质数据Service业务层处理
 */
@Service
public class YjjtSzDataServiceImpl implements IYjjtSzDataService
{
    @Autowired
    private YjjtSzDataMapper yjjtSzDataMapper;

    @Override
    public YjjtSzData selectYjjtSzDataById(Long id)
    {
        return yjjtSzDataMapper.selectYjjtSzDataById(id);
    }

    @Override
    public List<YjjtSzData> selectYjjtSzDataList(YjjtSzData szData)
    {
        return yjjtSzDataMapper.selectYjjtSzDataList(szData);
    }

    @Override
    public int insertYjjtSzData(YjjtSzData szData)
    {
        return yjjtSzDataMapper.insertYjjtSzData(szData);
    }

    @Override
    public int updateYjjtSzData(YjjtSzData szData)
    {
        return yjjtSzDataMapper.updateYjjtSzData(szData);
    }

    @Override
    public int deleteYjjtSzDataByIds(Long[] ids)
    {
        return yjjtSzDataMapper.deleteYjjtSzDataByIds(ids);
    }

    @Override
    public int deleteYjjtSzDataById(Long id)
    {
        return yjjtSzDataMapper.deleteYjjtSzDataById(id);
    }

    @Override
    public List<String> selectDistinctRvnmList()
    {
        return yjjtSzDataMapper.selectDistinctRvnmList();
    }

    @Override
    public List<Map<String, Object>> selectCountByDateRange(String beginDate, String endDate)
    {
        return yjjtSzDataMapper.selectCountByDateRange(beginDate, endDate);
    }

    @Override
    public Map<String, Object> selectTodayWeekMonthCount(String addvcd)
    {
        return yjjtSzDataMapper.selectTodayWeekMonthCount(addvcd);
    }
}
